===============
Getting Started
===============

To use PFAS_SAT, do the following steps:

1- Activate the environment::

        conda activate PFAS_SAT

2- Open python to run PFAS_SAT::

        python

3- Run PFAS_SAT in ipython::

        import PFAS_SAT as ps
        ps.PFAS_SAT()


Create new project
==================

.. image:: /Images/Start_Tab.png
   :scale: 60 %
   :alt: alternate text
   :align: left


.. image:: /Images/Define_Sys_Tab.png
   :scale: 60 %
   :alt: alternate text
   :align: left


.. image:: /Images/FA_Tab.png
   :scale: 60 %
   :alt: alternate text
   :align: left

|

Monte Carlo simulation
======================

You can define the uncertainty distributions for the input data and then run the Monte Carlo
simulation to study the effect of uncertainty/variability in the input data. 


.. image:: /Images/MC_Tab.png
   :scale: 60 %
   :alt: alternate text
   :align: left

.. image:: /Images/MC_Tab.png
   :alt: alternate text
   :align: left

.. image:: /Images/MC_Results_plot_Tab.png
   :alt: alternate text
   :align: left


User defined data and process models
====================================

You can import your own input data or developed process models to PFAS_SAT. 
